#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
import argparse

import technoap.device.apg7400a as usbmca

##############################################################
def main(args):

	binfile = None
	savefile = args.file

	try:
		counts = 0
		binfile = open(savefile, 'rb')

		while True:
			# In case of python version 2, it is 'str' type, so it is converted to 'bytes' type.
			data = binfile.read(1024 * 8)
			data = data if isinstance(data, bytes) else bytes(data)  #Convert to 'bytes' type for version 2.

			if len(data) <= 0:
				#If the data length is 0 or less, it is judged that all the data has been read,-> end.
				break

			listData = usbmca.listinfo.ListInfo.createInfoList(data)
			listCounts = len(listData)

			for i in range(listCounts):
				textline = "[%4d]: CH:%d, PHA = %5d, msec = %.6f" % (counts,
					listData[i].mChannel, listData[i].mPulseHeightAnalyzer,
					listData[i].mAbsoluteMilliseconds)
				print (textline)
				counts += 1

		binfile.close()
	except Exception as ex:
		print (ex)
	finally:
		if binfile is not None:
			binfile.close()


##############################################################
if __name__=='__main__':
	msg_file = 'Specify the event data file to display the data contents, ' \
			   'if not specified, display the contents of the ./usbmca.bin file.'
	parser = argparse.ArgumentParser(description='Display the contents of event data.')
	parser.add_argument('-f', '--file', default='./usbmca.bin', help=msg_file)
	args = parser.parse_args()
	main(args)

