#!/usr/bin/python
# -*- coding: utf-8 -*-

import os
import time
import array

from . import constant
from .common import common

from ... import ftdi


class APG7400ABase(ftdi.ftdi.FTDI):

	#########################################################
	__mNewVendorId = 0
	__mNewProductId = 0
	__mOldVendorId = None
	__mOldProductId = None
	__mIsSettingVIDPID = False

	#########################################################
	def __init__(self):
		super(APG7400ABase, self).__init__()
		self.__initializing()
		result = self.SetVIDPID(constant.APG7400A_VENDORID, constant.APG7400A_PRODUCTID)
		#self.mIsSettingVIDPID = ftdi.constant.FT_SUCCESS(result)

	#########################################################
	def __initializing(self, parentRun = False):
		if parentRun == True:
			super(APG7400ABase, self)._FTDI__initializing()
		#self.mIsSettingVIDPID = None
		

	#########################################################
	def InitialDevice(self, waitTime = 0.5):

		result = True

		retlist = array.array('I', [int(ftdi.constant.FT_OK) for i in range(8)])
		#retlist[0] = self.SetVIDPID(VENDORID, PRODUCTID)
		retlist[1] = self.ResetDevice()
		retlist[2] = self.SetBitMode(255, ftdi.constant.FT_BITMODE_RESET)
		retlist[3] = self.SetLatencyTimer(2)
		retlist[4] = self.SetTimeouts(100, 100)
		retlist[5] = self.SetFlowControl(ftdi.constant.FT_FLOW_RTS_CTS, 0, 0)
		retlist[6] = self.Purge(ftdi.constant.FT_PURGE_RX | ftdi.constant.FT_PURGE_TX)
		time.sleep(waitTime)
		
		for i in range(len(retlist)):
			if ftdi.constant.FT_SUCCESS(retlist[i]) != True:
				result = False
				break

		return result

	#########################################################
	def RequestOnly(self, command, value, chn = constant.CHNUM_CMN):
		txcommand = common.generateCommand(command, value, chn)
		result, txbytes = self.Write(txcommand, len(txcommand))
		return result, txbytes

	#########################################################
	def RequestCommand(self, command, value = 0, chn = constant.CHNUM_CMN):

		result = False
		txcmd = common._common__generateCommand(command, chn).decode()

		resulttx, txbytes = self.RequestOnly(command, value, chn)

		if ftdi.constant.FT_SUCCESS(resulttx) == True:
			resultrx, rxdata, rxbytes = self.Read(txbytes)
			rxcmd, rxvalue = common.analyzeCommand(rxdata)
			isSuccess = ftdi.constant.FT_SUCCESS(resultrx)

			if isSuccess == True and txbytes == rxbytes:
				if rxcmd == txcmd and rxvalue == value:
					result = True

		return result

	#########################################################
	@staticmethod
	def SetProductID():
		result = False
		
		if APG7400ABase.__mIsSettingVIDPID == False:
			result0, oldVID, oldPID = APG7400ABase.GetVIDPID()
			status0 = ftdi.constant.FT_SUCCESS(result0)
	
			if status0 == True:
				newVID = constant.APG7400A_VENDORID
				newPID = constant.APG7400A_PRODUCTID
				result1 = APG7400ABase.SetVIDPID(newVID, newPID)
				status1 = ftdi.constant.FT_SUCCESS(result1)
	
				if status1 == True:
					APG7400ABase.__mNewVendorId = newVID
					APG7400ABase.__mNewProductId = newPID
					APG7400ABase.__mOldVendorId = oldVID
					APG7400ABase.__mOldProductId = oldPID
					APG7400ABase.__mIsSettingVIDPID = True
					result = True
		else:
			result = True

		return result

	#########################################################
	@staticmethod
	def ResetProductID():

		result = False

		if APG7400ABase.__mIsSettingVIDPID == True:
			if APG7400ABase.__mOldVendorId is not None and APG7400ABase.__mOldProductId is not None:
				ret0th = APG7400ABase.SetVIDPID(APG7400ABase.__mOldVendorId, APG7400ABase.__mOldProductId)
				result = ftdi.constant.FT_SUCCESS(ret0th)
	
				if result == True:
					APG7400ABase.__mNewVendorId = APG7400ABase.__mOldVendorId
					APG7400ABase.__mNewProductId = APG7400ABase.__mOldProductId
					APG7400ABase.__mIsSettingVIDPID = False
		else:
			result = False

		return result


