#!/usr/bin/python
# -*- coding: utf-8 -*-

import array

from ... import num
from ... import ftdi
from . import constant
from .common import common

READ_BYTES = constant.HIST_READBLOCKBYTES
READ_MAXBLK = constant.HIST_READBLOCK


class Histogram(object):

	#####################################################################
	def __init__(self, dest):
		self.__initializing()
		self.mUSBMCA = dest
		self.mSpectrum = None

	#####################################################################
	def __initializing(self):
		self.mUSBMCA = None
		self.mLastException = None

	#########################################################
	def __getUseDestination(self, dest):
		_dest = dest if dest is not None else self.mUSBMCA
		return _dest

	#########################################################
	@staticmethod
	def getAdg2ReadBlocks(adg):
		bins = constant.PARAM_ADG_TOBINS(adg)
		rdblk = int(bins / 512)
		return rdblk

	#########################################################
	@staticmethod
	def getBins2ReadBlocks(bins):
		rdblk = int(bins / 512)
		return rdblk

	#########################################################
	def read(self, chn, blocks = READ_MAXBLK, dest = None):

		histdata = None
		usbmca = self.__getUseDestination(dest)

		try:
			result = True
			ret1st = usbmca.RequestCommand("HCHW", (chn - 1))

			if ret1st == True:
				rxdata = bytearray()

				for i in range(blocks):
					ret2nd, rxdata0 = self.__read(i, usbmca)

					if ret2nd != True:
						result = False
						break

					rxdata += rxdata0

				#########
				histdata = num.bitconverter.copyToArrayU32(rxdata)

				if num.byteorder.isBigmachine() == False:
					histdata.byteswap()
				
				self.mSpectrum = histdata
		except Exception as ex:
			self.mLastException = ex
			result = None

		return result, histdata

	#########################################################
	def __read(self, index, dest = None):
		
		result = False
		rxdata = None
		rxbyte = 0
		usbmca = self.__getUseDestination(dest)

		command = "HI%02X" % (index)
		ret0th, dummy = usbmca.RequestOnly(command, 0)

		if ret0th == ftdi.constant.FT_OK:
			ret1st, rxdata, rxbyte = usbmca.Read(READ_BYTES)

			if usbmca.isSuccess(ret1st) == True and rxbyte == READ_BYTES:
				result = True

		return result, rxdata



