#!/usr/bin/python
# -*- coding: utf-8 -*-

import os
import time
import copy
import array

from . import constant
from .common import common
from ... import num

from ... import ftdi

VENDORID  = 0x1ca6		#vendor  ID
PRODUCTID = 0x0001		#product ID

STATUS_LIST = [
	#common
	["RLT", constant.CHNUM_CMN, 6],
	#CH1
	["LVT", constant.CHNUM_1ST, 6],	["DDT", constant.CHNUM_1ST, 6],
	["TCR", constant.CHNUM_1ST, 3],	["TCT", constant.CHNUM_1ST, 4],
	["ICR", constant.CHNUM_1ST, 3],
	#CH2
	["LVT", constant.CHNUM_2ND, 6],	["DDT", constant.CHNUM_2ND, 6],
	["TCR", constant.CHNUM_2ND, 3],	["TCT", constant.CHNUM_2ND, 4],
	["ICR", constant.CHNUM_2ND, 3],
	#CH3
	["LVT", constant.CHNUM_3RD, 6],	["DDT", constant.CHNUM_3RD, 6],
	["TCR", constant.CHNUM_3RD, 3],	["TCT", constant.CHNUM_3RD, 4],
	["ICR", constant.CHNUM_3RD, 3],
	#CH4
	["LVT", constant.CHNUM_4TH, 6],	["DDT", constant.CHNUM_4TH, 6],
	["TCR", constant.CHNUM_4TH, 3],	["TCT", constant.CHNUM_4TH, 4],
	["ICR", constant.CHNUM_4TH, 3]
]

class status(object):

	#########################################################
	def __init__(self, usbmca = None):
		self.mStatusItemList = STATUS_LIST
		self.__initializing()
		self.mUSBMCA = usbmca

	#########################################################
	def __initializing(self):
		self.mUSBMCA = None
		self.clearStatus()

	#########################################################
	def settingUSBMCA(self, usbmca):
		self.mUSBMCA = usbmca

	#########################################################
	def clearStatus(self):
		self.mStatus = {}
		self.mSumBytes = 0

		for item0 in self.mStatusItemList:
			name = self.generateKey(item0[0], item0[1])
			self.mStatus[name,] = 0
			self.mSumBytes = self.mSumBytes + item0[2]

	#########################################################
	def readStatus(self, usbmca = None):

		result = False
		device0 = usbmca if usbmca is not None else self.mUSBMCA

		resulttx, txbytes = device0.RequestOnly('STUW', 0)

		if ftdi.constant.FT_SUCCESS(result) == True:
			resultrx, rxdata, rxbytes = device0.Read(94)

			if ftdi.constant.FT_SUCCESS(result) == True and rxbytes == 94:
				index = 0
				temp0 = bytearray(8)

				for item0 in self.mStatusItemList:
					#######
					name = self.generateKey(item0[0], item0[1])

					#######
					value = copy.deepcopy(temp0)

					if 0 < item0[2] and item0[2] < 8:
						zlength = 8 - item0[2]
						nlast = index + item0[2]
						value = temp0[0:zlength] + rxdata[index:nlast]

					value1 = num.bitconverter.toIntU64(value)
					self.mStatus[name,] = num.byteorder.ntoh64(value1)
					index = index + item0[2]

				result = True

		return result

	#########################################################
	def getElapsedSeconds(self):
		time0 = common.convertTimeDigitToSeconds(self.mStatus['RLT',])
		return time0

	#########################################################
	def getElapsedMilliseconds(self):
		time0 = common.convertTimeDigitToMilliseconds(self.mStatus['RLT',])
		return time0

	#########################################################
	def getLiveTimeNanoseconds(self, chn):
		name = status.generateKey('LVT', chn)
		value = common.convertTimeDigitToNanoseconds(self.mStatus[name,])
		return value

	#########################################################
	def getDeadTimeNanoseconds(self, chn):
		name = status.generateKey('DDT', chn)
		value = common.convertTimeDigitToNanoseconds(self.mStatus[name,])
		return value

	#########################################################
	@staticmethod
	def generateKey(name, chn):
		if chn == constant.CHNUM_CMN:
			keyname = name
		else:
			keyname = "%s%d" % (name, chn)

		return keyname



